==> jc-1.4.0.tar.gz: soot/grimp/internal/GInstanceOfExpr.h <==
// public class soot.grimp.internal.GInstanceOfExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8777675005b6ef2b soot_grimp_internal_GInstanceOfExpr
// @dep_class 4522a9ddedb3d65f soot_jimple_internal_AbstractInstanceOfExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceOfExpr

#include "soot/jimple/internal/AbstractInstanceOfExpr.h"

#ifndef _JC_soot_grimp_internal_GInstanceOfExpr_H_
#define _JC_soot_grimp_internal_GInstanceOfExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$sub_refs	_jc_soot_grimp_internal_GInstanceOfExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$sub_nonrefs	_jc_soot_grimp_internal_GInstanceOfExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$refs	_jc_soot_grimp_internal_GInstanceOfExpr$refs;
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$nonrefs	_jc_soot_grimp_internal_GInstanceOfExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$object	_jc_soot_grimp_internal_GInstanceOfExpr$object;

typedef const struct _jc_soot_grimp_internal_GInstanceOfExpr$vmethods	_jc_soot_grimp_internal_GInstanceOfExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GInstanceOfExpr$vtable	_jc_soot_grimp_internal_GInstanceOfExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GInstanceOfExpr$vtype	_jc_soot_grimp_internal_GInstanceOfExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GInstanceOfExpr$method$_init$743c179cbcd16e16(_jc_env *, struct _jc_soot_grimp_internal_GInstanceOfExpr$object *, struct _jc_object *, struct _jc_soot_Type$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GInstanceOfExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GInstanceOfExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GInstanceOfExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GInstanceOfExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceOfExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GInstanceOfExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceOfExpr$vmethods	soot_jimple_internal_AbstractInstanceOfExpr;
	_jc_soot_grimp_internal_GInstanceOfExpr$vmethods	soot_grimp_internal_GInstanceOfExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GInstanceOfExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GInstanceOfExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInstanceOfExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GInstanceOfExpr$refs {
    _jc_soot_grimp_internal_GInstanceOfExpr$sub_refs	soot_grimp_internal_GInstanceOfExpr;
    _jc_soot_jimple_internal_AbstractInstanceOfExpr$sub_refs	soot_jimple_internal_AbstractInstanceOfExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInstanceOfExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GInstanceOfExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceOfExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceOfExpr;
    _jc_soot_grimp_internal_GInstanceOfExpr$sub_nonrefs	soot_grimp_internal_GInstanceOfExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GInstanceOfExpr$object {
	_jc_soot_grimp_internal_GInstanceOfExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GInstanceOfExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GInstanceOfExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GInstanceOfExpr$vtype _jc_soot_grimp_internal_GInstanceOfExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GInstanceOfExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GInstanceOfExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GInstanceOfExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GInstanceOfExpr.h <==
// public class soot.grimp.internal.GInstanceOfExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8777675005b6ef2b soot_grimp_internal_GInstanceOfExpr
// @dep_class 4522a9ddedb3d65f soot_jimple_internal_AbstractInstanceOfExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceOfExpr

#include "soot/jimple/internal/AbstractInstanceOfExpr.h"

#ifndef _JC_soot_grimp_internal_GInstanceOfExpr_H_
#define _JC_soot_grimp_internal_GInstanceOfExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$sub_refs	_jc_soot_grimp_internal_GInstanceOfExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$sub_nonrefs	_jc_soot_grimp_internal_GInstanceOfExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$refs	_jc_soot_grimp_internal_GInstanceOfExpr$refs;
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$nonrefs	_jc_soot_grimp_internal_GInstanceOfExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GInstanceOfExpr$object	_jc_soot_grimp_internal_GInstanceOfExpr$object;

typedef const struct _jc_soot_grimp_internal_GInstanceOfExpr$vmethods	_jc_soot_grimp_internal_GInstanceOfExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GInstanceOfExpr$vtable	_jc_soot_grimp_internal_GInstanceOfExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GInstanceOfExpr$vtype	_jc_soot_grimp_internal_GInstanceOfExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GInstanceOfExpr$method$_init$743c179cbcd16e16(_jc_env *, struct _jc_soot_grimp_internal_GInstanceOfExpr$object *, struct _jc_object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GInstanceOfExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GInstanceOfExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GInstanceOfExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GInstanceOfExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GInstanceOfExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GInstanceOfExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceOfExpr$vmethods	soot_jimple_internal_AbstractInstanceOfExpr;
	_jc_soot_grimp_internal_GInstanceOfExpr$vmethods	soot_grimp_internal_GInstanceOfExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GInstanceOfExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GInstanceOfExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInstanceOfExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GInstanceOfExpr$refs {
    _jc_soot_grimp_internal_GInstanceOfExpr$sub_refs	soot_grimp_internal_GInstanceOfExpr;
    _jc_soot_jimple_internal_AbstractInstanceOfExpr$sub_refs	soot_jimple_internal_AbstractInstanceOfExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInstanceOfExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GInstanceOfExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceOfExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceOfExpr;
    _jc_soot_grimp_internal_GInstanceOfExpr$sub_nonrefs	soot_grimp_internal_GInstanceOfExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GInstanceOfExpr$object {
	_jc_soot_grimp_internal_GInstanceOfExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GInstanceOfExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GInstanceOfExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GInstanceOfExpr$vtype _jc_soot_grimp_internal_GInstanceOfExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GInstanceOfExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GInstanceOfExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GInstanceOfExpr_H_ */
